==> pyccnn-0.1-py3-none-any.whl: pyccnn/examples/run_bayes.py <==
import os
os.environ['CUDA_VISIBLE_DEVICES'] = '-1'

import numpy as np
import matplotlib.pyplot as plt
import tensorflow.compat.v1 as tf
from sklearn.model_selection import train_test_split
 
from pyccnn.core import activations, losses
from pyccnn.core.model import CCNN
from pyccnn.core.monitor import EarlyStoppingMonitor
from pyccnn.core.units.linear import BayesianLinear 
from pyccnn.core.units.perceptron import TensorflowPerceptron


def run():

    # ==================================================================================
    # DATA
    # ==================================================================================  
    def f(x, sigma):
        epsilon = np.random.randn(*x.shape) * sigma
        return 10. * np.sin(2 * np.pi * (x)) + epsilon
    
    train_size = 200
    noise = 1.0
    
    X = np.linspace(-0.5, 0.5, train_size).reshape(-1, 1)
    y = f(X, sigma=noise)
    X_train, X_valid, y_train, y_valid = train_test_split(X, y, test_size=0.3, random_state=0)
    
    # ==================================================================================
    # MODEL
    # ==================================================================================  
    # layer for outputs
    output_unit = BayesianLinear(alpha=0.1, beta=5.0)
    
    # layer for candidates
    candidate_unit = TensorflowPerceptron(activations=[activations.gaussian] * 5,
                                          loss_function=losses.fully_bayesian,
                                          stopping_rule=EarlyStoppingMonitor(1e-5, 500, 10000, normalize=True),
                                          optimizer=tf.train.AdamOptimizer,
                                          optimizer_args={'learning_rate': 0.01},
                                          batch_size=999999,
                                          regularizer=tf.nn.l2_loss,
                                          reg_penalty=1e-6)
    
    # cascade correlation network
    ccnn = CCNN(1, 1,
                output_unit=output_unit, candidate_unit=candidate_unit,
                metric_function=losses.fvu,
                lambda_param=0.8)
    
    # ==================================================================================
    # TRAINING
    # ==================================================================================  
    result = ccnn.train(X_train, y_train,
                        stopping_rule=EarlyStoppingMonitor(1e-5, 2, 20),
                        valid_X=X_valid, valid_y=y_valid)
    
    # ==================================================================================
    # PLOTTING
    # ==================================================================================      
    # generate predictions in interval
    X_test = np.linspace(-2, 2, 500).reshape((-1, 1))
    y_pred, y_pred_cov = ccnn.predict(X_test.reshape((-1, 1)))
    y_pred = y_pred.flatten()
    y_var = np.diag(y_pred_cov).flatten()
    lower_ci = y_pred - 1.96 * np.sqrt(y_var)
    upper_ci = y_pred + 1.96 * np.sqrt(y_var)
    
    # plot confidence intervals and test data
    fig, ax = plt.subplots(figsize=(5, 5))
    ax.plot(X_test, y_pred, color='blue', label='mean prediction')
    ax.plot(X_test, lower_ci, color='gray')
    ax.plot(X_test, upper_ci, color='gray')
    ax.fill_between(X_test.flatten(), lower_ci, upper_ci, alpha=0.1, color='gray', label='95% credible region')
    ax.scatter(X_train.flatten(), y_train.flatten(), color='black', s=5, label='train data points')
    ax.set_xlabel('x')
    ax.set_ylabel('y')
    ax.set_title('Bayesian Linear Regression for sin(x)')
    ax.legend(loc='best')
    plt.tight_layout()
    plt.show()


if __name__ == '__main__':
    run()

==> pyccnn-1.0-py3-none-any.whl: pyccnn/examples/run_bayes.py <==
import os
os.environ['CUDA_VISIBLE_DEVICES'] = '-1'
import numpy as np
import matplotlib.pyplot as plt
from sklearn.model_selection import train_test_split
 
from pyccnn.core.model import CCNN
from pyccnn.core.parser import load_config

def run():

    # data
    X = np.linspace(-0.5, 0.5, 100).reshape(-1, 1)
    y = 10. * np.sin(2 * np.pi * X) + np.random.randn(*X.shape)
    X_train, X_valid, y_train, y_valid = train_test_split(X, y, test_size=0.3, random_state=0)
    
    # model
    path = os.path.join(os.path.dirname(os.path.abspath(__file__)), 'configs', 'bayes.ini')
    network_args, train_args = load_config(path)
    ccnn = CCNN(**network_args)
    ccnn.train(X_train, y_train, valid_X=X_valid, valid_y=y_valid, **train_args)
    
    # generate predictions in interval
    X_test = np.linspace(-2, 2, 500).reshape((-1, 1))
    y_pred, y_pred_cov = ccnn.predict(X_test.reshape((-1, 1)))
    y_pred = y_pred.flatten()
    y_var = np.diag(y_pred_cov).flatten()
    lower_ci = y_pred - 1.96 * np.sqrt(y_var)
    upper_ci = y_pred + 1.96 * np.sqrt(y_var)
    
    # plot confidence intervals and test data
    _, ax = plt.subplots(figsize=(5, 5))
    ax.plot(X_test, y_pred, color='blue', label='mean prediction')
    ax.plot(X_test, lower_ci, color='gray')
    ax.plot(X_test, upper_ci, color='gray')
    ax.fill_between(X_test.flatten(), lower_ci, upper_ci, alpha=0.1, color='gray', label='95% credible region')
    ax.scatter(X_train.flatten(), y_train.flatten(), color='black', s=5, label='train data points')
    ax.set_xlabel('x')
    ax.set_ylabel('y')
    ax.set_title('Bayesian Linear Regression for sin(x)')
    ax.legend(loc='best')
    plt.tight_layout()
    plt.show()

if __name__ == '__main__':
    run()
